from .center import CenterViewSet
from .csrf import csrf_token_view
from .gender import GenderViewSet
from .stats import (
    ExaminationStatsView,
    VideoSegmentStatsView,
    SensitiveMetaStatsView,
    GeneralStatsView,
)

from .upload_views import (
    UploadFileView,
    UploadStatusView,
)

__all__ = [
    "CenterViewSet",
    'csrf_token_view',

    # Gender view
    "GenderViewSet",

    # Stats views
    'ExaminationStatsView',
    'VideoSegmentStatsView',
    'SensitiveMetaStatsView',
    "GeneralStatsView",

    # Upload views
    'UploadFileView',
    'UploadStatusView',

]
