# Generated by Django 6.0 on 2025-12-11 15:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0006_remove_processinghistory_content_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='videofile',
            name='uuid',
        ),
    ]
