# Generated by Django 6.0 on 2025-12-11 14:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('endoreg_db', '0003_remove_examination_description_de_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='processinghistory',
            name='id',
        ),
        migrations.AddField(
            model_name='processinghistory',
            name='file_name_hash',
            field=models.CharField(blank=True, editable=False, help_text='SHA-256 hash of the processed file name.', max_length=64, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='processinghistory',
            name='content_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='processinghistory',
            name='object_id',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
    ]
